@@ -25,14 +25,11 @@
 #' @export
 #'
 build_single_tree <- function(X, Y, m_feature, min_leaf,Inv_Cov_Y,Command){
-  NN=round(nrow(X)/min_leaf)*100
-  Model=rep( list(NULL), NN )
-  for (k in 1:length(Model)){
-    Model[[k]]=c(3,rep( list(NULL), 5 ))
-  }
-  i=0
-  Index=0:(nrow(X)-1)
+  NN=round(nrow(X)/min_leaf)*50
+  model=rep( list(NULL), NN )
+  i=1
+  Index=1:nrow(X)
   
-  split_node(X,Y,m_feature,Index,i,Model,min_leaf,Inv_Cov_Y,Command)
-  return(Model)
+  model=split_node(X,Y,m_feature,Index,i,model,min_leaf,Inv_Cov_Y,Command)
+  return(model)
 }
\ No newline at end of file
